@@ -23,7 +23,7 @@ for the JavaScript code in this file
 */
 var NAVTREE =
 [
-  [ "Main Page", "index.html", [
+  [ "My Project", "index.html", [
     [ "Namespaces", "namespaces.html", [
       [ "Namespace List", "namespaces.html", "namespaces_dup" ],
       [ "Namespace Members", "namespacemembers.html", [
@@ -56,14 +56,14 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"a00392.html",
-"a00630.html#a31b548d9f8334f3c4f9341eda3479982",
-"a00706.html#a9197cce11b83fae9f8ed3ef5ac79c2ed",
-"a00790.html#a65836d2070b943c8fecbad926d074de2",
-"a00886.html#add1df0176df3d03028f001f041f26d5c",
-"a00966.html#ab0a4759527012a701dcdf835659c9cd3",
-"a00990.html#afeda95bd5a6e6bbeda47db7fe3f56da1",
-"files.html"
+"a00551.html",
+"a00789.html#a1c85ed58e2e3362dd22fbdb815f2c5a3",
+"a00865.html#a9afad522b48b3d7a0fe296ec26e1484b",
+"a00961.html",
+"a01057.html#a9cf40ecf1b9b5c29507fe92a03f37a3c",
+"a01133.html#abede89f527e6fcfb1af012878a9978cc",
+"a01185.html#a6e1a910b772d22272d7876c4c29648e6a09ea5a566322e694b61b81303eeb369f",
+"a01205.html#aee0ff6081195e50afec79b3698c83748"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
